#

##

    	measures

    	structure supp
    		{
    			"form": {
    				"unit": "gram",
    				"amount": "283",
    				"servings": {
    					"listed": {
    						"serving size amount": "85",
    						"serving size unit": "GRM"
    					},
    					"calculated": {
    						"serving size amount": "85",
    						"servings per package": "283/85",
    						"foodNutrient per package multiplier": "283/100",
    						"labelNutrient per package multiplier": "283/85"
    					}
    				}
    			},
    			"energy": {
    				"ascertained": true,
    				"per package": {
    					"listed": [
    						"333.940",
    						"kcal"
    					],
    					"food calories": {
    						"decimal string": "333.940",
    						"fraction string": "16697/50"
    					}
    				}
    			},
    			"mass": {
    				"ascertained": true,
    				"per package": {
    					"grams": {
    						"fraction string": "283",
    						"decimal string": "283.00"
    					}
    				}
    			},
    			"volume": {
    				"ascertained": false,
    				"per package": {
    					"liters": {
    						"fraction string": "?",
    						"decimal string": "?"
    					}
    				}
    			}
    		}